from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TracesCls:
	"""Traces commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("traces", core, parent)

	def set(self, selection: enums.SelectionScope) -> None:
		"""SCPI: FORMat:DIMPort:TRACes \n
		Snippet: driver.formatPy.dimport.traces.set(selection = enums.SelectionScope.ALL) \n
		This command selects the data to be included in a data import file (see method RsFsw.MassMemory.Load.Trace.set) .
		For details on importing data see 'How to import traces'. \n
			:param selection: SINGle | ALL SINGle Only a single trace is selected for import, namely the one specified by the method RsFsw.MassMemory.Load.Trace.set command. ALL Imports several traces at once, overwriting the existing trace data for any active trace in the result display with the same trace number. Data from the import file for currently not active traces is not imported. The trace parameter for the method RsFsw.MassMemory.Load.Trace.set command is ignored.
		"""
		param = Conversions.enum_scalar_to_str(selection, enums.SelectionScope)
		self._core.io.write(f'FORMat:DIMPort:TRACes {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SelectionScope:
		"""SCPI: FORMat:DIMPort:TRACes \n
		Snippet: value: enums.SelectionScope = driver.formatPy.dimport.traces.get() \n
		This command selects the data to be included in a data import file (see method RsFsw.MassMemory.Load.Trace.set) .
		For details on importing data see 'How to import traces'. \n
			:return: selection: SINGle | ALL SINGle Only a single trace is selected for import, namely the one specified by the method RsFsw.MassMemory.Load.Trace.set command. ALL Imports several traces at once, overwriting the existing trace data for any active trace in the result display with the same trace number. Data from the import file for currently not active traces is not imported. The trace parameter for the method RsFsw.MassMemory.Load.Trace.set command is ignored."""
		response = self._core.io.query_str(f'FORMat:DIMPort:TRACes?')
		return Conversions.str_to_scalar_enum(response, enums.SelectionScope)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AchannelCls:
	"""Achannel commands group definition. 15 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("achannel", core, parent)

	@property
	def preset(self):
		"""preset commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_preset'):
			from .Preset import PresetCls
			self._preset = PresetCls(self._core, self._cmd_group)
		return self._preset

	@property
	def acPairs(self):
		"""acPairs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_acPairs'):
			from .AcPairs import AcPairsCls
			self._acPairs = AcPairsCls(self._core, self._cmd_group)
		return self._acPairs

	@property
	def bandwidth(self):
		"""bandwidth commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def cbwidth(self):
		"""cbwidth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbwidth'):
			from .Cbwidth import CbwidthCls
			self._cbwidth = CbwidthCls(self._core, self._cmd_group)
		return self._cbwidth

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def reference(self):
		"""reference commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_reference'):
			from .Reference import ReferenceCls
			self._reference = ReferenceCls(self._core, self._cmd_group)
		return self._reference

	@property
	def spacing(self):
		"""spacing commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_spacing'):
			from .Spacing import SpacingCls
			self._spacing = SpacingCls(self._core, self._cmd_group)
		return self._spacing

	@property
	def txChannel(self):
		"""txChannel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_txChannel'):
			from .TxChannel import TxChannelCls
			self._txChannel = TxChannelCls(self._core, self._cmd_group)
		return self._txChannel

	def clone(self) -> 'AchannelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AchannelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PpduCls:
	"""Ppdu commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ppdu", core, parent)

	def get(self, sc_detailed_object: enums.ScDetailedObject) -> List[float]:
		"""SCPI: FETCh:SCDetailed:POWer:PPDU \n
		Snippet: value: List[float] = driver.applications.k91Wlan.fetch.scDetailed.power.ppdu.get(sc_detailed_object = enums.ScDetailedObject.DPILot) \n
		Returns the power results for each PPDU for the selected subcarriers. These results are only available if the Signal
		Content Detailed result display is currently active (see method RsFsw.Layout.Add.Window.get_) . \n
			:param sc_detailed_object: HELTf | DPILot | LLTF HELTf Includes long training field (HE-LTF) subcarriers only DPILot Includes data and pilot subcarriers only LLTF Includes legacy long training field (L-LTF) subcarriers only Unit: dBm
			:return: powers: No help available"""
		param = Conversions.enum_scalar_to_str(sc_detailed_object, enums.ScDetailedObject)
		response = self._core.io.query_bin_or_ascii_float_list(f'FETCh:SCDetailed:POWer:PPDU? {param}')
		return response



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaxFrequencyCls:
	"""MaxFrequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("maxFrequency", core, parent)

	def set(self, max_frequncy: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:PPSPectrum:MAXFrequency \n
		Snippet: driver.applications.k6Pulse.calculate.ppSpectrum.maxFrequency.set(max_frequncy = 1.0, window = repcap.Window.Default) \n
		Defines the maximum frequency span for which the Spectrum is calculated. Internally, the span is limited by the number of
		possible interpolation samples (100 000) . \n
			:param max_frequncy: Range: 0 to 1/10 of sample rate, Unit: HZ
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(max_frequncy)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:PPSPectrum:MAXFrequency {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:PPSPectrum:MAXFrequency \n
		Snippet: value: float = driver.applications.k6Pulse.calculate.ppSpectrum.maxFrequency.get(window = repcap.Window.Default) \n
		Defines the maximum frequency span for which the Spectrum is calculated. Internally, the span is limited by the number of
		possible interpolation samples (100 000) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: max_frequncy: Range: 0 to 1/10 of sample rate, Unit: HZ"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:PPSPectrum:MAXFrequency?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class McOffsetCls:
	"""McOffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mcOffset", core, parent)

	def set(self, offset: float, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: [SENSe]:FREQuency:CENTer[:CC<cc>]:MCOFfset \n
		Snippet: driver.applications.k14Xnr5G.sense.frequency.center.cc.mcOffset.set(offset = 1.0, carrierComponent = repcap.CarrierComponent.Default) \n
		This command defines the frequency offset of a component carrier.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select the global MC frequency as the reference point for the frequency offset (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Orel.set) . \n
			:param offset: numeric value • Component carrier offset: frequency offset relative to the first component carrier in Hz. Unit: Hz
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.decimal_value_to_str(offset)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'SENSe:FREQuency:CENTer:CC{carrierComponent_cmd_val}:MCOFfset {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> float:
		"""SCPI: [SENSe]:FREQuency:CENTer[:CC<cc>]:MCOFfset \n
		Snippet: value: float = driver.applications.k14Xnr5G.sense.frequency.center.cc.mcOffset.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command defines the frequency offset of a component carrier.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select the global MC frequency as the reference point for the frequency offset (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Orel.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: offset: numeric value • Component carrier offset: frequency offset relative to the first component carrier in Hz. Unit: Hz"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'SENSe:FREQuency:CENTer:CC{carrierComponent_cmd_val}:MCOFfset?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: INPut:EATT:AUTO \n
		Snippet: driver.inputPy.eatt.auto.set(state = False) \n
		This command turns automatic selection of the electronic attenuation on and off. If on, electronic attenuation reduces
		the mechanical attenuation whenever possible. This command requires the electronic attenuation hardware option. It is not
		available if the optional 'Digital Baseband' interface is active. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'INPut:EATT:AUTO {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def set(self, state: bool) -> None:
		"""SCPI: CONFigure:WLAN:GTIMe:AUTO \n
		Snippet: driver.applications.k91Wlan.configure.wlan.gtime.auto.set(state = False) \n
		This remote control command specifies whether the guard time of the input signal is automatically detected or specified
		manually (IEEE 802.11n or ac only) . \n
			:param state: ON | 1 The guard time is detected automatically according to method RsFsw.Applications.K91_Wlan.Configure.Wlan.Gtime.Auto.TypePy.set. OFF | 0 The guard time is defined by the method RsFsw.Applications.K91_Wlan.Configure.Wlan.Gtime.Select.set command.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CONFigure:WLAN:GTIMe:AUTO {param}')

	def get(self) -> bool:
		"""SCPI: CONFigure:WLAN:GTIMe:AUTO \n
		Snippet: value: bool = driver.applications.k91Wlan.configure.wlan.gtime.auto.get() \n
		This remote control command specifies whether the guard time of the input signal is automatically detected or specified
		manually (IEEE 802.11n or ac only) . \n
			:return: state: ON | 1 The guard time is detected automatically according to method RsFsw.Applications.K91_Wlan.Configure.Wlan.Gtime.Auto.TypePy.set. OFF | 0 The guard time is defined by the method RsFsw.Applications.K91_Wlan.Configure.Wlan.Gtime.Select.set command."""
		response = self._core.io.query_str(f'CONFigure:WLAN:GTIMe:AUTO?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'AutoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AutoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EattCls:
	"""Eatt commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("eatt", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, attenuation: float) -> None:
		"""SCPI: INPut:EATT \n
		Snippet: driver.applications.k14Xnr5G.inputPy.eatt.set(attenuation = 1.0) \n
		This command defines the electronic attenuation level. If the current reference level is not compatible with an
		attenuation that has been set manually, the command also adjusts the reference level. This command is available with the
		optional Electronic Attenuator, but not if you are using the optional Digital Baseband Input. \n
			:param attenuation: Attenuation level in dB. Unit: dB
		"""
		param = Conversions.decimal_value_to_str(attenuation)
		self._core.io.write(f'INPut:EATT {param}')

	def get(self) -> float:
		"""SCPI: INPut:EATT \n
		Snippet: value: float = driver.applications.k14Xnr5G.inputPy.eatt.get() \n
		This command defines the electronic attenuation level. If the current reference level is not compatible with an
		attenuation that has been set manually, the command also adjusts the reference level. This command is available with the
		optional Electronic Attenuator, but not if you are using the optional Digital Baseband Input. \n
			:return: attenuation: Attenuation level in dB. Unit: dB"""
		response = self._core.io.query_str(f'INPut:EATT?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'EattCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EattCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NcorrectionCls:
	"""Ncorrection commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ncorrection", core, parent)

	@property
	def calibration(self):
		"""calibration commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_calibration'):
			from .Calibration import CalibrationCls
			self._calibration = CalibrationCls(self._core, self._cmd_group)
		return self._calibration

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:POWer:NCORrection \n
		Snippet: driver.applications.k14Xnr5G.sense.power.ncorrection.set(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:POWer:NCORrection {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:POWer:NCORrection \n
		Snippet: value: bool = driver.applications.k14Xnr5G.sense.power.ncorrection.get() \n
		No command help available \n
			:return: state: No help available"""
		response = self._core.io.query_str(f'SENSe:POWer:NCORrection?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'NcorrectionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NcorrectionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: INPut:IQ:FULLscale:AUTO \n
		Snippet: driver.inputPy.iq.fullscale.auto.set(state = False) \n
		This command defines whether the full scale level (i.e. the maximum input power on the Baseband Input connector) is
		defined automatically according to the reference level, or manually. \n
			:param state: ON | 1 Automatic definition OFF | 0 Manual definition according to method RsFsw.Applications.K6_Pulse.InputPy.Iq.Fullscale.Level.set
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'INPut:IQ:FULLscale:AUTO {param}')



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:LTE:MBSFn:SUBFrame<sf>:STATe \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.lte.mbsfn.subframe.state.set(state = False, carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default) \n
		This command turns MBSFN transmission in specific subframes on and off.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on LTE-CRS coexistence (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Lte.State.set) . \n
			:param state: ON | OFF | 1 | 0
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
		"""
		param = Conversions.bool_to_str(state)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:LTE:MBSFn:SUBFrame{subframe_cmd_val}:STATe {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default) -> bool:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:LTE:MBSFn:SUBFrame<sf>:STATe \n
		Snippet: value: bool = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.lte.mbsfn.subframe.state.get(carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default) \n
		This command turns MBSFN transmission in specific subframes on and off.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on LTE-CRS coexistence (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Lte.State.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
			:return: state: ON | OFF | 1 | 0"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:LTE:MBSFn:SUBFrame{subframe_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UnitCls:
	"""Unit commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("unit", core, parent)

	def set(self, unit: str) -> None:
		"""SCPI: [SENSe]:CORRection:TRANsducer:UNIT \n
		Snippet: driver.sense.correction.transducer.unit.set(unit = '1') \n
		This command selects the unit of the transducer factor. Before you can use the command, you have to select and turn on a
		transducer. \n
			:param unit: string as defined in table below
		"""
		param = Conversions.value_to_quoted_str(unit)
		self._core.io.write(f'SENSe:CORRection:TRANsducer:UNIT {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:CORRection:TRANsducer:UNIT \n
		Snippet: value: str = driver.sense.correction.transducer.unit.get() \n
		This command selects the unit of the transducer factor. Before you can use the command, you have to select and turn on a
		transducer. \n
			:return: unit: string as defined in table below"""
		response = self._core.io.query_str(f'SENSe:CORRection:TRANsducer:UNIT?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def set(self, level: float) -> None:
		"""SCPI: [SENSe]:PMETer:TRIGger:LEVel \n
		Snippet: driver.applications.k18AmplifierEt.sense.pmeter.trigger.level.set(level = 1.0) \n
		This command defines the trigger level for external power triggers. This command requires the use of a Rohde & Schwarz
		power sensor. For a list of supported sensors, see the datasheet. \n
			:param level: -20 to +20 dBm Range: -20 dBm to 20 dBm, Unit: DBM
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SENSe:PMETer:TRIGger:LEVel {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:PMETer:TRIGger:LEVel \n
		Snippet: value: float = driver.applications.k18AmplifierEt.sense.pmeter.trigger.level.get() \n
		This command defines the trigger level for external power triggers. This command requires the use of a Rohde & Schwarz
		power sensor. For a list of supported sensors, see the datasheet. \n
			:return: level: -20 to +20 dBm Range: -20 dBm to 20 dBm, Unit: DBM"""
		response = self._core.io.query_str(f'SENSe:PMETer:TRIGger:LEVel?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SoffsetCls:
	"""Soffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("soffset", core, parent)

	def set(self, sensor_offset: float, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: [SENSe]:PMETer<p>:SOFFset \n
		Snippet: driver.sense.pmeter.soffset.set(sensor_offset = 1.0, powerMeter = repcap.PowerMeter.Default) \n
		Takes the specified offset into account for the measured power. Only available if [SENSe:]PMETer{p}:ROFFset[:STATe] is
		disabled. \n
			:param sensor_offset: Unit: DB
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.decimal_value_to_str(sensor_offset)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'SENSe:PMETer{powerMeter_cmd_val}:SOFFset {param}')

	def get(self, powerMeter=repcap.PowerMeter.Default) -> float:
		"""SCPI: [SENSe]:PMETer<p>:SOFFset \n
		Snippet: value: float = driver.sense.pmeter.soffset.get(powerMeter = repcap.PowerMeter.Default) \n
		Takes the specified offset into account for the measured power. Only available if [SENSe:]PMETer{p}:ROFFset[:STATe] is
		disabled. \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: sensor_offset: Unit: DB"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'SENSe:PMETer{powerMeter_cmd_val}:SOFFset?')
		return Conversions.str_to_float(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.Utilities import trim_str_response
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, carrierComponent=repcap.CarrierComponent.Default) -> str:
		"""SCPI: CALCulate<n>:LIMit<li>[:CC<cc>]:SUMMary:SERRor:MAXimum:RESult \n
		Snippet: value: str = driver.applications.k10Xlte.calculate.limit.cc.summary.serror.maximum.result.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, carrierComponent = repcap.CarrierComponent.Default) \n
		This command queries the results of the sampling error limit check. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: limit_check: The type of limit (average or maximum) that is queried depends on the last syntax element. FAILED Limit check has failed. PASSED Limit check has passed. NOTEVALUATED Limits have not been evaluated."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:CC{carrierComponent_cmd_val}:SUMMary:SERRor:MAXimum:RESult?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SemCls:
	"""Sem commands group definition. 5 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sem", core, parent)

	@property
	def amPower(self):
		"""amPower commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_amPower'):
			from .AmPower import AmPowerCls
			self._amPower = AmPowerCls(self._core, self._cmd_group)
		return self._amPower

	@property
	def iff(self):
		"""iff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iff'):
			from .Iff import IffCls
			self._iff = IffCls(self._core, self._cmd_group)
		return self._iff

	@property
	def ntab(self):
		"""ntab commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ntab'):
			from .Ntab import NtabCls
			self._ntab = NtabCls(self._core, self._cmd_group)
		return self._ntab

	@property
	def ntxu(self):
		"""ntxu commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ntxu'):
			from .Ntxu import NtxuCls
			self._ntxu = NtxuCls(self._core, self._cmd_group)
		return self._ntxu

	def clone(self) -> 'SemCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SemCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PilotsCls:
	"""Pilots commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pilots", core, parent)

	def set(self, mode: enums.PilotSeqMode) -> None:
		"""SCPI: [SENSe]:TRACking:PILots \n
		Snippet: driver.applications.k91Wlan.sense.tracking.pilots.set(mode = enums.PilotSeqMode.DETected) \n
		In case tracking is used, the used pilot sequence has an effect on the measurement results. For details see 'Tracking the
		phase drift, timing jitter and gain'. \n
			:param mode: STANdard | DETected STANdard The pilot sequence is determined according to the corresponding WLAN standard. In case the pilot generation algorithm of the device under test (DUT) has a problem, the non-standard-conform pilot sequence might affect the measurement results, or the R&S FSW WLAN application might not synchronize at all onto the signal generated by the DUT. DETected The pilot sequence detected in the WLAN signal to be analyzed is used by the R&S FSW WLAN application. In case the pilot generation algorithm of the device under test (DUT) has a problem, the non-standard-conform pilot sequence will not affect the measurement results. In case the pilot sequence generated by the DUT is correct, it is recommended that you use the 'According to Standard' setting because it generates more accurate measurement results.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.PilotSeqMode)
		self._core.io.write(f'SENSe:TRACking:PILots {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PilotSeqMode:
		"""SCPI: [SENSe]:TRACking:PILots \n
		Snippet: value: enums.PilotSeqMode = driver.applications.k91Wlan.sense.tracking.pilots.get() \n
		In case tracking is used, the used pilot sequence has an effect on the measurement results. For details see 'Tracking the
		phase drift, timing jitter and gain'. \n
			:return: mode: STANdard | DETected STANdard The pilot sequence is determined according to the corresponding WLAN standard. In case the pilot generation algorithm of the device under test (DUT) has a problem, the non-standard-conform pilot sequence might affect the measurement results, or the R&S FSW WLAN application might not synchronize at all onto the signal generated by the DUT. DETected The pilot sequence detected in the WLAN signal to be analyzed is used by the R&S FSW WLAN application. In case the pilot generation algorithm of the device under test (DUT) has a problem, the non-standard-conform pilot sequence will not affect the measurement results. In case the pilot sequence generated by the DUT is correct, it is recommended that you use the 'According to Standard' setting because it generates more accurate measurement results."""
		response = self._core.io.query_str(f'SENSe:TRACking:PILots?')
		return Conversions.str_to_scalar_enum(response, enums.PilotSeqMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CidCls:
	"""Cid commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cid", core, parent)

	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> float:
		"""SCPI: FETCh[:CC<cc>]:PLC:CID \n
		Snippet: value: float = driver.applications.k14Xnr5G.fetch.cc.plc.cid.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command queries the cell ID. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: identity: No help available"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'FETCh:CC{carrierComponent_cmd_val}:PLC:CID?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	def set(self, lo_frequency: float) -> None:
		"""SCPI: [SENSe]:CONFigure:MODE:SYSTem:LO:FREQuency \n
		Snippet: driver.applications.k30NoiseFigure.sense.configure.mode.system.lo.frequency.set(lo_frequency = 1.0) \n
		This command defines the frequency for DUTs with a fixed LO. \n
			:param lo_frequency: Range: 0 Hz to 100 GHz, Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(lo_frequency)
		self._core.io.write(f'SENSe:CONFigure:MODE:SYSTem:LO:FREQuency {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CONFigure:MODE:SYSTem:LO:FREQuency \n
		Snippet: value: float = driver.applications.k30NoiseFigure.sense.configure.mode.system.lo.frequency.get() \n
		This command defines the frequency for DUTs with a fixed LO. \n
			:return: lo_frequency: Range: 0 Hz to 100 GHz, Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:CONFigure:MODE:SYSTem:LO:FREQuency?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WidthCls:
	"""Width commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("width", core, parent)

	def set(self, time: float) -> None:
		"""SCPI: RIQ:PFM:WIDTh \n
		Snippet: driver.applications.k6Pulse.riq.pfm.width.set(time = 1.0) \n
		Sets/queries the pulse width for polynomial FM type reference I/Q data. \n
			:param time: Unit: S
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'RIQ:PFM:WIDTh {param}')

	def get(self) -> float:
		"""SCPI: RIQ:PFM:WIDTh \n
		Snippet: value: float = driver.applications.k6Pulse.riq.pfm.width.get() \n
		Sets/queries the pulse width for polynomial FM type reference I/Q data. \n
			:return: time: Unit: S"""
		response = self._core.io.query_str(f'RIQ:PFM:WIDTh?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MrangeCls:
	"""Mrange commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mrange", core, parent)

	def set(self, range_py: enums.PowerVectorErrorMode) -> None:
		"""SCPI: CONFigure:WLAN:PVERror:MRANge \n
		Snippet: driver.applications.k91Wlan.configure.wlan.pvError.mrange.set(range_py = enums.PowerVectorErrorMode.ALL) \n
		This remote control command defines or queries whether the Peak Vector Error results are calculated over the complete
		PPDU or just over the PSDU. This command is supported for 802.11b and 802.11g (DSSS) only. \n
			:param range_py: ALL | PSDU ALL Peak Vector Error results are calculated over the complete PPDU PSDU Peak Vector Error results are calculated over the PSDU only
		"""
		param = Conversions.enum_scalar_to_str(range_py, enums.PowerVectorErrorMode)
		self._core.io.write(f'CONFigure:WLAN:PVERror:MRANge {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PowerVectorErrorMode:
		"""SCPI: CONFigure:WLAN:PVERror:MRANge \n
		Snippet: value: enums.PowerVectorErrorMode = driver.applications.k91Wlan.configure.wlan.pvError.mrange.get() \n
		This remote control command defines or queries whether the Peak Vector Error results are calculated over the complete
		PPDU or just over the PSDU. This command is supported for 802.11b and 802.11g (DSSS) only. \n
			:return: range_py: ALL | PSDU ALL Peak Vector Error results are calculated over the complete PPDU PSDU Peak Vector Error results are calculated over the PSDU only"""
		response = self._core.io.query_str(f'CONFigure:WLAN:PVERror:MRANge?')
		return Conversions.str_to_scalar_enum(response, enums.PowerVectorErrorMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MinimumCls:
	"""Minimum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("minimum", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:BURSt:PREamble:MINimum \n
		Snippet: value: str = driver.applications.k91Wlan.fetch.burst.preamble.minimum.get() \n
		This command returns the average, maximum or minimum of the 'Preamble Power per PPDU' (in dBm) . All symbols prior to the
		first data symbol of the PPDU are used to calculate the preamble power. All analyzed PPDUs, up to the statistic length,
		take part in the statistical evaluation. \n
			:return: result: list"""
		response = self._core.io.query_str(f'FETCh:BURSt:PREamble:MINimum?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SvFailedCls:
	"""SvFailed commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("svFailed", core, parent)

	def set(self, state: enums.AutoMode) -> None:
		"""SCPI: [SENSe]:SWEep:SVFailed \n
		Snippet: driver.applications.k40PhaseNoise.sense.sweep.svFailed.set(state = enums.AutoMode.AUTO) \n
		This command turns repeated tries to start the measurement if signal verification fails on and off. \n
			:param state: ON | OFF | AUTO If on, the application tries to verify the signal once and then aborts the measurement if verification has failed.
		"""
		param = Conversions.enum_scalar_to_str(state, enums.AutoMode)
		self._core.io.write(f'SENSe:SWEep:SVFailed {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AutoMode:
		"""SCPI: [SENSe]:SWEep:SVFailed \n
		Snippet: value: enums.AutoMode = driver.applications.k40PhaseNoise.sense.sweep.svFailed.get() \n
		This command turns repeated tries to start the measurement if signal verification fails on and off. \n
			:return: state: ON | OFF | AUTO If on, the application tries to verify the signal once and then aborts the measurement if verification has failed."""
		response = self._core.io.query_str(f'SENSe:SWEep:SVFailed?')
		return Conversions.str_to_scalar_enum(response, enums.AutoMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RelativeCls:
	"""Relative commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("relative", core, parent)

	def set(self, level: float) -> None:
		"""SCPI: TRIGger[:SEQuence]:LEVel:AM:RELative \n
		Snippet: driver.trigger.sequence.level.am.relative.set(level = 1.0) \n
		The command sets the level when AM-modulated signals are used as trigger source. For triggering to be successful, the
		measurement time must cover at least 5 periods of the audio signal. \n
			:param level: Range: -100 to +100, Unit: %
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'TRIGger:SEQuence:LEVel:AM:RELative {param}')

	def get(self) -> float:
		"""SCPI: TRIGger[:SEQuence]:LEVel:AM:RELative \n
		Snippet: value: float = driver.trigger.sequence.level.am.relative.get() \n
		The command sets the level when AM-modulated signals are used as trigger source. For triggering to be successful, the
		measurement time must cover at least 5 periods of the audio signal. \n
			:return: level: Range: -100 to +100, Unit: %"""
		response = self._core.io.query_str(f'TRIGger:SEQuence:LEVel:AM:RELative?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DpdCls:
	"""Dpd commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dpd", core, parent)

	def set(self, filename: str, store=repcap.Store.Default) -> None:
		"""SCPI: MMEMory:STORe<n>:DPD \n
		Snippet: driver.applications.k18AmplifierEt.massMemory.store.dpd.set(filename = '1', store = repcap.Store.Default) \n
		This command generates and stores a waveform containing the DPD in a file you have specified.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- DPD method 'Generate Predistorted Waveform File' has to be selected (method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.Method.set = WFILe)
			- The DPD calculation has been initiated with method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.File.Generate.set. \n
			:param filename: String containing the file name.
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
		"""
		param = Conversions.value_to_quoted_str(filename)
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		self._core.io.write(f'MMEMory:STORe{store_cmd_val}:DPD {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PiaqCls:
	"""Piaq commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("piaq", core, parent)

	def set(self, detector: enums.EvaluateType, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: CALCulate<n>:TRACe<t>[:VALue]:PIAQ \n
		Snippet: driver.applications.k6Pulse.calculate.trace.value.piaq.set(detector = enums.EvaluateType.ITIMe, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		Defines which signal component (I/Q) is evaluated in which trace for the 'Pulse I and Q' result display. By default, the
		I component is displayed by trace 1, while the Q component is displayed by trace 4. This setting is not available for any
		other results displays. \n
			:param detector: ITIMe | QTIMe ITIMe The I component is evaluated by the selected trace. QTIMe The Q component is evaluated by the selected trace.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(detector, enums.EvaluateType)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:VALue:PIAQ {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> enums.EvaluateType:
		"""SCPI: CALCulate<n>:TRACe<t>[:VALue]:PIAQ \n
		Snippet: value: enums.EvaluateType = driver.applications.k6Pulse.calculate.trace.value.piaq.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		Defines which signal component (I/Q) is evaluated in which trace for the 'Pulse I and Q' result display. By default, the
		I component is displayed by trace 1, while the Q component is displayed by trace 4. This setting is not available for any
		other results displays. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: detector: ITIMe | QTIMe ITIMe The I component is evaluated by the selected trace. QTIMe The Q component is evaluated by the selected trace."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:VALue:PIAQ?')
		return Conversions.str_to_scalar_enum(response, enums.EvaluateType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InterpolateCls:
	"""Interpolate commands group definition. 4 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("interpolate", core, parent)

	@property
	def wiener(self):
		"""wiener commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_wiener'):
			from .Wiener import WienerCls
			self._wiener = WienerCls(self._core, self._cmd_group)
		return self._wiener

	def set(self, interpolation: enums.DemodInterpolation) -> None:
		"""SCPI: [SENSe]:DEMod:INTerpolate \n
		Snippet: driver.applications.k91Wlan.sense.demod.interpolate.set(interpolation = enums.DemodInterpolation.LINear) \n
		No command help available \n
			:param interpolation: WIENer | LINear WIENer The unused subcarriers of the channel estimation fields (1xHE-LTF, 2xHE-LTF) are determined by Wiener interpolation. The estimated channel is smoothed. The Wiener interpolation overwrites the used subcarrier sampling points. In case all subcarriers are used (4xHE-LTF) , sampling points for all subcarriers are available. The channel is smoothed. LINear The unused subcarriers of the channel estimation fields (1xHE-LTF, 2xHE-LTF) are determined by linear interpolation. Linear interpolation preserves the used subcarrier sampling points. In case all subcarriers are used (4xHE-LTF) , the available sampling points for all subcarriers are preserved, and no interpolation is applied.
		"""
		param = Conversions.enum_scalar_to_str(interpolation, enums.DemodInterpolation)
		self._core.io.write(f'SENSe:DEMod:INTerpolate {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DemodInterpolation:
		"""SCPI: [SENSe]:DEMod:INTerpolate \n
		Snippet: value: enums.DemodInterpolation = driver.applications.k91Wlan.sense.demod.interpolate.get() \n
		No command help available \n
			:return: interpolation: WIENer | LINear WIENer The unused subcarriers of the channel estimation fields (1xHE-LTF, 2xHE-LTF) are determined by Wiener interpolation. The estimated channel is smoothed. The Wiener interpolation overwrites the used subcarrier sampling points. In case all subcarriers are used (4xHE-LTF) , sampling points for all subcarriers are available. The channel is smoothed. LINear The unused subcarriers of the channel estimation fields (1xHE-LTF, 2xHE-LTF) are determined by linear interpolation. Linear interpolation preserves the used subcarrier sampling points. In case all subcarriers are used (4xHE-LTF) , the available sampling points for all subcarriers are preserved, and no interpolation is applied."""
		response = self._core.io.query_str(f'SENSe:DEMod:INTerpolate?')
		return Conversions.str_to_scalar_enum(response, enums.DemodInterpolation)

	def clone(self) -> 'InterpolateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = InterpolateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:SELect \n
		Snippet: driver.applications.k91Wlan.display.window.subwindow.select.set(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default) \n
		This command sets the focus on the selected result display window. This window is then the active window.
		For measurements with multiple results in subwindows, the command also selects the subwindow. Use this command to select
		the (sub) window before querying trace data. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:SELect')

	def set_with_opc(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:SELect \n
		Snippet: driver.applications.k91Wlan.display.window.subwindow.select.set_with_opc(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default) \n
		This command sets the focus on the selected result display window. This window is then the active window.
		For measurements with multiple results in subwindows, the command also selects the subwindow. Use this command to select
		the (sub) window before querying trace data. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:SELect', opc_timeout_ms)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self, result_type: enums.DdemResultType, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:RESult \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.result.get(result_type = enums.DdemResultType.ADR, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param result_type: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.DdemResultType)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:RESult? {param}')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DeltaMarkerCls:
	"""DeltaMarker commands group definition. 16 total commands, 8 Subgroups, 0 group commands
	Repeated Capability: DeltaMarker, default value after init: DeltaMarker.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("deltaMarker", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_deltaMarker_get', 'repcap_deltaMarker_set', repcap.DeltaMarker.Nr1)

	def repcap_deltaMarker_set(self, deltaMarker: repcap.DeltaMarker) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to DeltaMarker.Default
		Default value after init: DeltaMarker.Nr1"""
		self._cmd_group.set_repcap_enum_value(deltaMarker)

	def repcap_deltaMarker_get(self) -> repcap.DeltaMarker:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def aoff(self):
		"""aoff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aoff'):
			from .Aoff import AoffCls
			self._aoff = AoffCls(self._core, self._cmd_group)
		return self._aoff

	@property
	def mburst(self):
		"""mburst commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mburst'):
			from .Mburst import MburstCls
			self._mburst = MburstCls(self._core, self._cmd_group)
		return self._mburst

	@property
	def trace(self):
		"""trace commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def y(self):
		"""y commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_y'):
			from .Y import YCls
			self._y = YCls(self._core, self._cmd_group)
		return self._y

	@property
	def maximum(self):
		"""maximum commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_maximum'):
			from .Maximum import MaximumCls
			self._maximum = MaximumCls(self._core, self._cmd_group)
		return self._maximum

	@property
	def minimum(self):
		"""minimum commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_minimum'):
			from .Minimum import MinimumCls
			self._minimum = MinimumCls(self._core, self._cmd_group)
		return self._minimum

	@property
	def x(self):
		"""x commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_x'):
			from .X import XCls
			self._x = XCls(self._core, self._cmd_group)
		return self._x

	def clone(self) -> 'DeltaMarkerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DeltaMarkerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModulationCls:
	"""Modulation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("modulation", core, parent)

	def set(self, modulation: enums.ModulationDl, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default, allocation=repcap.Allocation.Default, codeword=repcap.Codeword.Default) -> None:
		"""SCPI: CONFigure[:LTE]:DL[:CC<cc>]:SUBFrame<sf>:ALLoc<al>[:CW<cw>]:MODulation \n
		Snippet: driver.applications.k10Xlte.configure.lte.downlink.cc.subframe.alloc.cw.modulation.set(modulation = enums.ModulationDl.Q1K, carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default, allocation = repcap.Allocation.Default, codeword = repcap.Codeword.Default) \n
		This command selects the modulation of an allocation in a downlink subframe. \n
			:param modulation: QPSK QPSK modulation QAM16 16QAM modulation QAM64 64QAM modulation QAM256 256QAM modulation Q1K 1024QAM modulation
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
			:param allocation: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param codeword: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cw')
		"""
		param = Conversions.enum_scalar_to_str(modulation, enums.ModulationDl)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		allocation_cmd_val = self._cmd_group.get_repcap_cmd_value(allocation, repcap.Allocation)
		codeword_cmd_val = self._cmd_group.get_repcap_cmd_value(codeword, repcap.Codeword)
		self._core.io.write(f'CONFigure:LTE:DL:CC{carrierComponent_cmd_val}:SUBFrame{subframe_cmd_val}:ALLoc{allocation_cmd_val}:CW{codeword_cmd_val}:MODulation {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default, allocation=repcap.Allocation.Default, codeword=repcap.Codeword.Default) -> enums.ModulationDl:
		"""SCPI: CONFigure[:LTE]:DL[:CC<cc>]:SUBFrame<sf>:ALLoc<al>[:CW<cw>]:MODulation \n
		Snippet: value: enums.ModulationDl = driver.applications.k10Xlte.configure.lte.downlink.cc.subframe.alloc.cw.modulation.get(carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default, allocation = repcap.Allocation.Default, codeword = repcap.Codeword.Default) \n
		This command selects the modulation of an allocation in a downlink subframe. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
			:param allocation: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param codeword: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cw')
			:return: modulation: QPSK QPSK modulation QAM16 16QAM modulation QAM64 64QAM modulation QAM256 256QAM modulation Q1K 1024QAM modulation"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		allocation_cmd_val = self._cmd_group.get_repcap_cmd_value(allocation, repcap.Allocation)
		codeword_cmd_val = self._cmd_group.get_repcap_cmd_value(codeword, repcap.Codeword)
		response = self._core.io.query_str(f'CONFigure:LTE:DL:CC{carrierComponent_cmd_val}:SUBFrame{subframe_cmd_val}:ALLoc{allocation_cmd_val}:CW{codeword_cmd_val}:MODulation?')
		return Conversions.str_to_scalar_enum(response, enums.ModulationDl)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AchannelCls:
	"""Achannel commands group definition. 20 total commands, 13 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("achannel", core, parent)

	@property
	def aaChannel(self):
		"""aaChannel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aaChannel'):
			from .AaChannel import AaChannelCls
			self._aaChannel = AaChannelCls(self._core, self._cmd_group)
		return self._aaChannel

	@property
	def acPairs(self):
		"""acPairs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_acPairs'):
			from .AcPairs import AcPairsCls
			self._acPairs = AcPairsCls(self._core, self._cmd_group)
		return self._acPairs

	@property
	def agChannels(self):
		"""agChannels commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_agChannels'):
			from .AgChannels import AgChannelsCls
			self._agChannels = AgChannelsCls(self._core, self._cmd_group)
		return self._agChannels

	@property
	def gap(self):
		"""gap commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_gap'):
			from .Gap import GapCls
			self._gap = GapCls(self._core, self._cmd_group)
		return self._gap

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def preset(self):
		"""preset commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_preset'):
			from .Preset import PresetCls
			self._preset = PresetCls(self._core, self._cmd_group)
		return self._preset

	@property
	def reference(self):
		"""reference commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_reference'):
			from .Reference import ReferenceCls
			self._reference = ReferenceCls(self._core, self._cmd_group)
		return self._reference

	@property
	def sbcount(self):
		"""sbcount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sbcount'):
			from .Sbcount import SbcountCls
			self._sbcount = SbcountCls(self._core, self._cmd_group)
		return self._sbcount

	@property
	def sblock(self):
		"""sblock commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_sblock'):
			from .Sblock import SblockCls
			self._sblock = SblockCls(self._core, self._cmd_group)
		return self._sblock

	@property
	def ssetup(self):
		"""ssetup commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ssetup'):
			from .Ssetup import SsetupCls
			self._ssetup = SsetupCls(self._core, self._cmd_group)
		return self._ssetup

	@property
	def txChannel(self):
		"""txChannel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_txChannel'):
			from .TxChannel import TxChannelCls
			self._txChannel = TxChannelCls(self._core, self._cmd_group)
		return self._txChannel

	@property
	def uaaChannel(self):
		"""uaaChannel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_uaaChannel'):
			from .UaaChannel import UaaChannelCls
			self._uaaChannel = UaaChannelCls(self._core, self._cmd_group)
		return self._uaaChannel

	@property
	def evm(self):
		"""evm commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_evm'):
			from .Evm import EvmCls
			self._evm = EvmCls(self._core, self._cmd_group)
		return self._evm

	def clone(self) -> 'AchannelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AchannelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PaeCls:
	"""Pae commands group definition. 7 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pae", core, parent)

	@property
	def ichannel(self):
		"""ichannel commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_ichannel'):
			from .Ichannel import IchannelCls
			self._ichannel = IchannelCls(self._core, self._cmd_group)
		return self._ichannel

	@property
	def pconsumption(self):
		"""pconsumption commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pconsumption'):
			from .Pconsumption import PconsumptionCls
			self._pconsumption = PconsumptionCls(self._core, self._cmd_group)
		return self._pconsumption

	@property
	def qchannel(self):
		"""qchannel commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_qchannel'):
			from .Qchannel import QchannelCls
			self._qchannel = QchannelCls(self._core, self._cmd_group)
		return self._qchannel

	def clone(self) -> 'PaeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PaeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaximumCls:
	"""Maximum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("maximum", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:BURSt:MCPower:MAXimum \n
		Snippet: value: str = driver.applications.k91Wlan.fetch.burst.mcPower.maximum.get() \n
		This command returns the MIMO cross power (average, maximum or minimum value) in dB for the IEEE 802.11n (MIMO) standard.
		For details see 'Modulation accuracy, flatness and tolerance parameters'. \n
			:return: result: Stream 1 result ... Stream n result"""
		response = self._core.io.query_str(f'FETCh:BURSt:MCPower:MAXimum?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, offset: float, externalGen=repcap.ExternalGen.Nr1) -> None:
		"""SCPI: SOURce:EXTernal<gen>:FREQuency:OFFSet \n
		Snippet: driver.source.external.frequency.offset.set(offset = 1.0, externalGen = repcap.ExternalGen.Nr1) \n
		This command defines the frequency offset of the generator with reference to the analyzer frequency. This command is only
		valid if External Generator Control (R&S FSW-B10) is installed and active. Select the offset such that the frequency
		range of the generator is not exceeded if the following formula is applied to the start and stop frequency of the
		analyzer: \n
			:param offset: numeric value, specified in Hz, kHz, MHz or GHz, rounded to the nearest Hz Unit: HZ
			:param externalGen: optional repeated capability selector. Default value: Nr1
		"""
		param = Conversions.decimal_value_to_str(offset)
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		self._core.io.write(f'SOURce:EXTernal{externalGen_cmd_val}:FREQuency:OFFSet {param}')

	def get(self, externalGen=repcap.ExternalGen.Nr1) -> float:
		"""SCPI: SOURce:EXTernal<gen>:FREQuency:OFFSet \n
		Snippet: value: float = driver.source.external.frequency.offset.get(externalGen = repcap.ExternalGen.Nr1) \n
		This command defines the frequency offset of the generator with reference to the analyzer frequency. This command is only
		valid if External Generator Control (R&S FSW-B10) is installed and active. Select the offset such that the frequency
		range of the generator is not exceeded if the following formula is applied to the start and stop frequency of the
		analyzer: \n
			:param externalGen: optional repeated capability selector. Default value: Nr1
			:return: offset: numeric value, specified in Hz, kHz, MHz or GHz, rounded to the nearest Hz Unit: HZ"""
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		response = self._core.io.query_str(f'SOURce:EXTernal{externalGen_cmd_val}:FREQuency:OFFSet?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhonesCls:
	"""Phones commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phones", core, parent)

	def set(self, state: bool, outputConnector=repcap.OutputConnector.Default) -> None:
		"""SCPI: OUTPut<up>:ADEMod[:ONLine]:PHONes \n
		Snippet: driver.output.ademod.online.phones.set(state = False, outputConnector = repcap.OutputConnector.Default) \n
		In addition to sending the output to the IF/VIDEO/DEMOD output connector (on the rear panel of the R&S FSW) , it can also
		be output to headphones connected on the front panel ([Phones] connector) . CAUTION: To protect your hearing, make sure
		that the volume setting is not too high before putting on the headphones. If you do not hear output on the connected
		headphones despite having enabled both general online demod output method RsFsw.Output.Ademod.Online.State.set and this
		command, adjust the volume setting. (Using method RsFsw.System.Speaker.Volume.set. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.bool_to_str(state)
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		self._core.io.write(f'OUTPut{outputConnector_cmd_val}:ADEMod:ONLine:PHONes {param}')

	def get(self, outputConnector=repcap.OutputConnector.Default) -> bool:
		"""SCPI: OUTPut<up>:ADEMod[:ONLine]:PHONes \n
		Snippet: value: bool = driver.output.ademod.online.phones.get(outputConnector = repcap.OutputConnector.Default) \n
		In addition to sending the output to the IF/VIDEO/DEMOD output connector (on the rear panel of the R&S FSW) , it can also
		be output to headphones connected on the front panel ([Phones] connector) . CAUTION: To protect your hearing, make sure
		that the volume setting is not too high before putting on the headphones. If you do not hear output on the connected
		headphones despite having enabled both general online demod output method RsFsw.Output.Ademod.Online.State.set and this
		command, adjust the volume setting. (Using method RsFsw.System.Speaker.Volume.set. \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		response = self._core.io.query_str(f'OUTPut{outputConnector_cmd_val}:ADEMod:ONLine:PHONes?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaximumCls:
	"""Maximum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("maximum", core, parent)

	def get(self) -> float:
		"""SCPI: FETCh:TSKew:MAXimum \n
		Snippet: value: float = driver.applications.k9X11Ad.fetch.tskew.maximum.get() \n
		This command returns the average, maximum or minimum time skew for the PPDU in ps. For details see 'Time Skew [s]'. \n
			:return: result: No help available"""
		response = self._core.io.query_str(f'FETCh:TSKew:MAXimum?')
		return Conversions.str_to_float(response)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XCls:
	"""X commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("x", core, parent)

	def get(self, trace_type: enums.TraceTypeK10X, window=repcap.Window.Default) -> List[float]:
		"""SCPI: TRACe<n>[:DATA]:X \n
		Snippet: value: List[float] = driver.applications.k10Xlte.trace.data.x.get(trace_type = enums.TraceTypeK10X.FAL1, window = repcap.Window.Default) \n
		This command queries the horizontal trace data for each measurement point (x-axis values) . In combination with method
		RsFsw.Trace.Data.get_, you can thus query the coordinates of each measurement point. \n
			:param trace_type: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trace')
			:return: trace_xdata: No help available"""
		param = Conversions.enum_scalar_to_str(trace_type, enums.TraceTypeK10X)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_bin_or_ascii_float_list(f'FORMAT REAL,32;TRACe{window_cmd_val}:DATA:X? {param}')
		return response



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PlcCls:
	"""Plc commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("plc", core, parent)

	@property
	def cid(self):
		"""cid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cid'):
			from .Cid import CidCls
			self._cid = CidCls(self._core, self._cmd_group)
		return self._cid

	@property
	def detection(self):
		"""detection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_detection'):
			from .Detection import DetectionCls
			self._detection = DetectionCls(self._core, self._cmd_group)
		return self._detection

	@property
	def pclass(self):
		"""pclass commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pclass'):
			from .Pclass import PclassCls
			self._pclass = PclassCls(self._core, self._cmd_group)
		return self._pclass

	def clone(self) -> 'PlcCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PlcCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PmSettlingCls:
	"""PmSettling commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pmSettling", core, parent)

	def set(self, xaxis: enums.XaXisPmSettling, yaxis: enums.YaXisItems, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:DISTribution:HOP:PMSettling \n
		Snippet: driver.applications.k60Transient.calculate.distribution.hop.pmSettling.set(xaxis = enums.XaXisPmSettling.PMSLength, yaxis = enums.YaXisItems.COUNt, window = repcap.Window.Default) \n
		Configures the Parameter Distribution result display for hop PM settling parameters. \n
			:param xaxis: PMSLength | PMSPoint | PMSTime PMSPoint PM settling point PMSTime PM settling time PMSLength PM settled length
			:param yaxis: COUNt | OCCurrence Parameter to be displayed on the y-axis. COUNt Number of hops in which the parameter value occurred. OCCurance Percentage of all measured hops in which the parameter value occurred.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('xaxis', xaxis, DataType.Enum, enums.XaXisPmSettling), ArgSingle('yaxis', yaxis, DataType.Enum, enums.YaXisItems))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:DISTribution:HOP:PMSettling {param}'.rstrip())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InsertCls:
	"""Insert commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("insert", core, parent)

	def set(self, file_path: str, touchStone=repcap.TouchStone.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:BASeband:USER:SLISt<sli>:INSert \n
		Snippet: driver.sense.correction.fresponse.baseband.user.slist.insert.set(file_path = '1', touchStone = repcap.TouchStone.Default) \n
		Loads a new Touchstone file for the current configuration. The maximum number of files per configuration is 15. The new
		file is added below the entry specified by the <sli> index. All other entries with a higher suffix are moved down by one
		position. To change the order of the files, use the [SENSe:]CORRection:FRESponse<si>:USER:SLISt<sli>:MOVE command.
		To determine which files are available, use [SENSe:]CORRection:FRESponse<si>:USER:SLISt<sli>:CATalog?. \n
			:param file_path: string Path and file name The file extension of the Touchstone file must correspond to the number of ports included in the file. For example, a file containing 4 parameters for S11, S22, S12 and S21 must have the extension .s2p. The default directory for Touchstone files is C:/R_S/INSTR/USER/Fresponse.
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
		"""
		param = Conversions.value_to_quoted_str(file_path)
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		self._core.io.write(f'SENSe:CORRection:FRESponse:BASeband:USER:SLISt{touchStone_cmd_val}:INSert {param}')

	def get(self, touchStone=repcap.TouchStone.Default) -> str:
		"""SCPI: [SENSe]:CORRection:FRESponse:BASeband:USER:SLISt<sli>:INSert \n
		Snippet: value: str = driver.sense.correction.fresponse.baseband.user.slist.insert.get(touchStone = repcap.TouchStone.Default) \n
		Loads a new Touchstone file for the current configuration. The maximum number of files per configuration is 15. The new
		file is added below the entry specified by the <sli> index. All other entries with a higher suffix are moved down by one
		position. To change the order of the files, use the [SENSe:]CORRection:FRESponse<si>:USER:SLISt<sli>:MOVE command.
		To determine which files are available, use [SENSe:]CORRection:FRESponse<si>:USER:SLISt<sli>:CATalog?. \n
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
			:return: file_path: string Path and file name The file extension of the Touchstone file must correspond to the number of ports included in the file. For example, a file containing 4 parameters for S11, S22, S12 and S21 must have the extension .s2p. The default directory for Touchstone files is C:/R_S/INSTR/USER/Fresponse."""
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		response = self._core.io.query_str(f'SENSe:CORRection:FRESponse:BASeband:USER:SLISt{touchStone_cmd_val}:INSert?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BbPowerCls:
	"""BbPower commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bbPower", core, parent)

	def set(self, level: float) -> None:
		"""SCPI: TRIGger[:SEQuence]:LEVel:BBPower \n
		Snippet: driver.trigger.sequence.level.bbPower.set(level = 1.0) \n
		This command sets the level of the baseband power trigger. This command is available for the optional 'Digital Baseband'
		interface and the optional 'Analog Baseband' interface. \n
			:param level: Range: -50 dBm to +20 dBm, Unit: DBM
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'TRIGger:SEQuence:LEVel:BBPower {param}')

	def get(self) -> float:
		"""SCPI: TRIGger[:SEQuence]:LEVel:BBPower \n
		Snippet: value: float = driver.trigger.sequence.level.bbPower.get() \n
		This command sets the level of the baseband power trigger. This command is available for the optional 'Digital Baseband'
		interface and the optional 'Analog Baseband' interface. \n
			:return: level: Range: -50 dBm to +20 dBm, Unit: DBM"""
		response = self._core.io.query_str(f'TRIGger:SEQuence:LEVel:BBPower?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.LisnType, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:LISN[:TYPE] \n
		Snippet: driver.inputPy.lisn.typePy.set(type_py = enums.LisnType.ENV216, inputIx = repcap.InputIx.Default) \n
		This command turns automatic control of a LISN on and off. It also selects the type of network. \n
			:param type_py: ENV216 R&S ENV 216 / AMN6500: two phases and highpass are controllable. ENV432 R&S ENV 432: four phases are controllable. ENV4200 R&S ENV 4200: four phases are controllable. ESH2Z5 R&S ESH2-Z5: four phases (incl. protective earth) are controllable. ESH3Z5 R&S ESH3-Z5: two phases (incl. protective earth) are controllable. FOURphase R&S ESH2-Z5: four phases (incl. protective earth) are controllable. OFF Turns off remote control of the LISN. TWOPhase R&S ESH3-Z5: two phases (incl. protective earth) are controllable.
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.LisnType)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:LISN:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.LisnType:
		"""SCPI: INPut<ip>:LISN[:TYPE] \n
		Snippet: value: enums.LisnType = driver.inputPy.lisn.typePy.get(inputIx = repcap.InputIx.Default) \n
		This command turns automatic control of a LISN on and off. It also selects the type of network. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: type_py: ENV216 R&S ENV 216 / AMN6500: two phases and highpass are controllable. ENV432 R&S ENV 432: four phases are controllable. ENV4200 R&S ENV 4200: four phases are controllable. ESH2Z5 R&S ESH2-Z5: four phases (incl. protective earth) are controllable. ESH3Z5 R&S ESH3-Z5: two phases (incl. protective earth) are controllable. FOURphase R&S ESH2-Z5: four phases (incl. protective earth) are controllable. OFF Turns off remote control of the LISN. TWOPhase R&S ESH3-Z5: two phases (incl. protective earth) are controllable."""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:LISN:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.LisnType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StatusCls:
	"""Status commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("status", core, parent)

	def get(self) -> bool:
		"""SCPI: FETCh:PSERvoing:OPERation:STATus \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.fetch.pservoing.operation.status.get() \n
		Queries the status of the power servoing operation. \n
			:return: state: ON | OFF | 1 | 0"""
		response = self._core.io.query_str(f'FETCh:PSERvoing:OPERation:STATus?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CouplingCls:
	"""Coupling commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coupling", core, parent)

	def set(self, coupling_type: enums.CouplingTypeB, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:IQ:OSC:COUPling \n
		Snippet: driver.applications.iqAnalyzer.inputPy.iq.osc.coupling.set(coupling_type = enums.CouplingTypeB.AC, inputIx = repcap.InputIx.Default) \n
		Determines the coupling of the oscilloscope to the R&S FSW. \n
			:param coupling_type: (enum or string) No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_ext_scalar_to_str(coupling_type, enums.CouplingTypeB)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:IQ:OSC:COUPling {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.CouplingTypeB:
		"""SCPI: INPut<ip>:IQ:OSC:COUPling \n
		Snippet: value: enums.CouplingTypeB = driver.applications.iqAnalyzer.inputPy.iq.osc.coupling.get(inputIx = repcap.InputIx.Default) \n
		Determines the coupling of the oscilloscope to the R&S FSW. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: coupling_type: (enum or string) No help available"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:IQ:OSC:COUPling?')
		return Conversions.str_to_scalar_enum_ext(response, enums.CouplingTypeB)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CcCls:
	"""Cc commands group definition. 179 total commands, 17 Subgroups, 0 group commands
	Repeated Capability: CarrierComponent, default value after init: CarrierComponent.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cc", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_carrierComponent_get', 'repcap_carrierComponent_set', repcap.CarrierComponent.Nr1)

	def repcap_carrierComponent_set(self, carrierComponent: repcap.CarrierComponent) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to CarrierComponent.Default
		Default value after init: CarrierComponent.Nr1"""
		self._cmd_group.set_repcap_enum_value(carrierComponent)

	def repcap_carrierComponent_get(self) -> repcap.CarrierComponent:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def bf(self):
		"""bf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bf'):
			from .Bf import BfCls
			self._bf = BfCls(self._core, self._cmd_group)
		return self._bf

	@property
	def bw(self):
		"""bw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bw'):
			from .Bw import BwCls
			self._bw = BwCls(self._core, self._cmd_group)
		return self._bw

	@property
	def demod(self):
		"""demod commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_demod'):
			from .Demod import DemodCls
			self._demod = DemodCls(self._core, self._cmd_group)
		return self._demod

	@property
	def dfRange(self):
		"""dfRange commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dfRange'):
			from .DfRange import DfRangeCls
			self._dfRange = DfRangeCls(self._core, self._cmd_group)
		return self._dfRange

	@property
	def euids(self):
		"""euids commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_euids'):
			from .Euids import EuidsCls
			self._euids = EuidsCls(self._core, self._cmd_group)
		return self._euids

	@property
	def fnnf(self):
		"""fnnf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fnnf'):
			from .Fnnf import FnnfCls
			self._fnnf = FnnfCls(self._core, self._cmd_group)
		return self._fnnf

	@property
	def frame(self):
		"""frame commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_frame'):
			from .Frame import FrameCls
			self._frame = FrameCls(self._core, self._cmd_group)
		return self._frame

	@property
	def ftConfig(self):
		"""ftConfig commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ftConfig'):
			from .FtConfig import FtConfigCls
			self._ftConfig = FtConfigCls(self._core, self._cmd_group)
		return self._ftConfig

	@property
	def idc(self):
		"""idc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_idc'):
			from .Idc import IdcCls
			self._idc = IdcCls(self._core, self._cmd_group)
		return self._idc

	@property
	def lte(self):
		"""lte commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_lte'):
			from .Lte import LteCls
			self._lte = LteCls(self._core, self._cmd_group)
		return self._lte

	@property
	def pamapping(self):
		"""pamapping commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_pamapping'):
			from .Pamapping import PamappingCls
			self._pamapping = PamappingCls(self._core, self._cmd_group)
		return self._pamapping

	@property
	def plc(self):
		"""plc commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_plc'):
			from .Plc import PlcCls
			self._plc = PlcCls(self._core, self._cmd_group)
		return self._plc

	@property
	def rfuc(self):
		"""rfuc commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_rfuc'):
			from .Rfuc import RfucCls
			self._rfuc = RfucCls(self._core, self._cmd_group)
		return self._rfuc

	@property
	def rpa(self):
		"""rpa commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_rpa'):
			from .Rpa import RpaCls
			self._rpa = RpaCls(self._core, self._cmd_group)
		return self._rpa

	@property
	def ssCa(self):
		"""ssCa commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ssCa'):
			from .SsCa import SsCaCls
			self._ssCa = SsCaCls(self._core, self._cmd_group)
		return self._ssCa

	@property
	def ssBlock(self):
		"""ssBlock commands group. 14 Sub-classes, 0 commands."""
		if not hasattr(self, '_ssBlock'):
			from .SsBlock import SsBlockCls
			self._ssBlock = SsBlockCls(self._core, self._cmd_group)
		return self._ssBlock

	@property
	def ssCount(self):
		"""ssCount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ssCount'):
			from .SsCount import SsCountCls
			self._ssCount = SsCountCls(self._core, self._cmd_group)
		return self._ssCount

	def clone(self) -> 'CcCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CcCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImpedanceCls:
	"""Impedance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("impedance", core, parent)

	def set(self, impedance: int) -> None:
		"""SCPI: [SENSe]:IQ:IMPedance \n
		Snippet: driver.applications.iqAnalyzer.sense.iq.impedance.set(impedance = 1) \n
		No command help available \n
			:param impedance: No help available
		"""
		param = Conversions.decimal_value_to_str(impedance)
		self._core.io.write(f'SENSe:IQ:IMPedance {param}')

	def get(self) -> int:
		"""SCPI: [SENSe]:IQ:IMPedance \n
		Snippet: value: int = driver.applications.iqAnalyzer.sense.iq.impedance.get() \n
		No command help available \n
			:return: impedance: No help available"""
		response = self._core.io.query_str(f'SENSe:IQ:IMPedance?')
		return Conversions.str_to_int(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PrsCls:
	"""Prs commands group definition. 10 total commands, 10 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("prs", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def slot(self):
		"""slot commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_slot'):
			from .Slot import SlotCls
			self._slot = SlotCls(self._core, self._cmd_group)
		return self._slot

	@property
	def noRbs(self):
		"""noRbs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_noRbs'):
			from .NoRbs import NoRbsCls
			self._noRbs = NoRbsCls(self._core, self._cmd_group)
		return self._noRbs

	@property
	def srb(self):
		"""srb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srb'):
			from .Srb import SrbCls
			self._srb = SrbCls(self._core, self._cmd_group)
		return self._srb

	@property
	def lpStart(self):
		"""lpStart commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lpStart'):
			from .LpStart import LpStartCls
			self._lpStart = LpStartCls(self._core, self._cmd_group)
		return self._lpStart

	@property
	def lprs(self):
		"""lprs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lprs'):
			from .Lprs import LprsCls
			self._lprs = LprsCls(self._core, self._cmd_group)
		return self._lprs

	@property
	def npId(self):
		"""npId commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_npId'):
			from .NpId import NpIdCls
			self._npId = NpIdCls(self._core, self._cmd_group)
		return self._npId

	@property
	def kpComb(self):
		"""kpComb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_kpComb'):
			from .KpComb import KpCombCls
			self._kpComb = KpCombCls(self._core, self._cmd_group)
		return self._kpComb

	@property
	def kpOffset(self):
		"""kpOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_kpOffset'):
			from .KpOffset import KpOffsetCls
			self._kpOffset = KpOffsetCls(self._core, self._cmd_group)
		return self._kpOffset

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	def clone(self) -> 'PrsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PrsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhaseCls:
	"""Phase commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phase", core, parent)

	def set(self, type_py: enums.PhaseTrackingMethod) -> None:
		"""SCPI: [SENSe][:LTE]:UL:TRACking:PHASe \n
		Snippet: driver.applications.k10Xlte.sense.lte.uplink.tracking.phase.set(type_py = enums.PhaseTrackingMethod.OFF) \n
		This command selects the phase tracking method. \n
			:param type_py: OFF Deactivate phase tracking PIL Pilot only PILP Pilot and payload
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.PhaseTrackingMethod)
		self._core.io.write(f'SENSe:LTE:UL:TRACking:PHASe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PhaseTrackingMethod:
		"""SCPI: [SENSe][:LTE]:UL:TRACking:PHASe \n
		Snippet: value: enums.PhaseTrackingMethod = driver.applications.k10Xlte.sense.lte.uplink.tracking.phase.get() \n
		This command selects the phase tracking method. \n
			:return: type_py: OFF Deactivate phase tracking PIL Pilot only PILP Pilot and payload"""
		response = self._core.io.query_str(f'SENSe:LTE:UL:TRACking:PHASe?')
		return Conversions.str_to_scalar_enum(response, enums.PhaseTrackingMethod)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DeviceFootprintCls:
	"""DeviceFootprint commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("deviceFootprint", core, parent)

	def get(self) -> str:
		"""SCPI: SYSTem:DFPRint \n
		Snippet: value: str = driver.system.deviceFootprint.get() \n
		Creates an *.xml file with information on installed hardware, software, image and FPGA versions. The *.xml file is stored
		under C:/R_S/INSTR/devicedata/xml/DeviceFootprint_* on the instrument. It is also output to the remote interface as
		binary data. \n
			:return: xxx: Contents of the xml file in binary format."""
		response = self._core.io.query_str(f'SYSTem:DFPRint?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RestoreCls:
	"""Restore commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("restore", core, parent)

	def set(self, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:PRESet:RESTore \n
		Snippet: driver.sense.espectrum.preset.restore.set(subBlock = repcap.SubBlock.Default) \n
		This command restores the default configurations of predefined SEM standards. Note that the command will overwrite
		customized standards that have the same name as predefined standards. \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
		"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:PRESet:RESTore')

	def set_with_opc(self, subBlock=repcap.SubBlock.Default, opc_timeout_ms: int = -1) -> None:
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		"""SCPI: [SENSe]:ESPectrum<sb>:PRESet:RESTore \n
		Snippet: driver.sense.espectrum.preset.restore.set_with_opc(subBlock = repcap.SubBlock.Default) \n
		This command restores the default configurations of predefined SEM standards. Note that the command will overwrite
		customized standards that have the same name as predefined standards. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:ESPectrum{subBlock_cmd_val}:PRESet:RESTore', opc_timeout_ms)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, alpha: float, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:FILTer:ALPHa:GAP<gap>[:AUTO] \n
		Snippet: driver.sense.power.achannel.filterPy.alpha.gap.auto.set(alpha = 1.0, gapChannel = repcap.GapChannel.Default) \n
		This command defines the roll-off factor for the specified gap (CACLR) channel's weighting filter in all sub block gaps. \n
			:param alpha: Roll-off factor Range: 0 to 1
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = Conversions.decimal_value_to_str(alpha)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'SENSe:POWer:ACHannel:FILTer:ALPHa:GAP{gapChannel_cmd_val}:AUTO {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RightCls:
	"""Right commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("right", core, parent)

	def set(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CALCulate<n>:DELTamarker<m>:MAXimum:RIGHt \n
		Snippet: driver.calculate.deltaMarker.maximum.right.set(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command moves a delta marker to the next positive peak value on the trace. The search includes only measurement
		values to the right of the current marker position. In the spectrogram, the command moves a marker horizontally to the
		maximum level in the currently selected frame. The vertical marker position remains the same. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:MAXimum:RIGHt', opc_timeout_ms)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MbsfnCls:
	"""Mbsfn commands group definition. 7 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mbsfn", core, parent)

	@property
	def ai(self):
		"""ai commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ai'):
			from .Ai import AiCls
			self._ai = AiCls(self._core, self._cmd_group)
		return self._ai

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def subframe(self):
		"""subframe commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_subframe'):
			from .Subframe import SubframeCls
			self._subframe = SubframeCls(self._core, self._cmd_group)
		return self._subframe

	def clone(self) -> 'MbsfnCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MbsfnCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:DDEMod:KDATa:PRBS:PATTern:AUTO \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.kdata.prbs.pattern.auto.set(state = False) \n
		If enabled, the R&S FSW VSA application assumes the pattern is part of the PRBS sequence. If disabled, configure the
		setting using the [SENSe:]DDEMod:KDATa:PRBS:PATTern[:STATe] command. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:DDEMod:KDATa:PRBS:PATTern:AUTO {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:DDEMod:KDATa:PRBS:PATTern:AUTO \n
		Snippet: value: bool = driver.applications.k70Vsa.sense.ddemod.kdata.prbs.pattern.auto.get() \n
		If enabled, the R&S FSW VSA application assumes the pattern is part of the PRBS sequence. If disabled, configure the
		setting using the [SENSe:]DDEMod:KDATa:PRBS:PATTern[:STATe] command. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		response = self._core.io.query_str(f'SENSe:DDEMod:KDATa:PRBS:PATTern:AUTO?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class McgdCls:
	"""Mcgd commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mcgd", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self) -> None:
		"""SCPI: CALibration:MCGD \n
		Snippet: driver.applications.k17Mcgd.calibration.mcgd.set() \n
		This command initiates a new calibration. You can synchronize to the end of the measurement as usual with *OPC, *OPC? or
		*WAI. You can execute this command in two different modes: synchronous and asynchronous. In asynchronous mode, the
		command starts a new calibration and immediately continues processing subsequent commands while calibration is performed
		in the background. In synchronous mode, further processing only continues when the calibration is finished.
		For synchronous mode, add ;*WAI to the end of the method RsFsw.Applications.K17_Mcgd.Calibration.Mcgd.set command. This
		is useful, for example, if you want to run a script file which does not know when the calibration finishes. \n
		"""
		self._core.io.write(f'CALibration:MCGD')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CALibration:MCGD \n
		Snippet: driver.applications.k17Mcgd.calibration.mcgd.set_with_opc() \n
		This command initiates a new calibration. You can synchronize to the end of the measurement as usual with *OPC, *OPC? or
		*WAI. You can execute this command in two different modes: synchronous and asynchronous. In asynchronous mode, the
		command starts a new calibration and immediately continues processing subsequent commands while calibration is performed
		in the background. In synchronous mode, further processing only continues when the calibration is finished.
		For synchronous mode, add ;*WAI to the end of the method RsFsw.Applications.K17_Mcgd.Calibration.Mcgd.set command. This
		is useful, for example, if you want to run a script file which does not know when the calibration finishes. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALibration:MCGD', opc_timeout_ms)

	def clone(self) -> 'McgdCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = McgdCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, mode: enums.DataDemodModeK91) -> None:
		"""SCPI: [SENSe]:DEMod:DATA \n
		Snippet: driver.applications.k91Wlan.sense.demod.data.set(mode = enums.DataDemodModeK91.ACDScarrier) \n
		Defines when in the demodulation process the bitstream is determined and thus which results are available. See also 'BER
		and CWER'. \n
			:param mode: ACDScarrier | ALBDecoder ACDScarrier (Default:) No channel decoding is performed. Processing time is reduced, but BER and CWER results are not available. ALBDecoder Decoding is performed, providing BER and CWER results. Measurement time is increased compared to non-decoding process.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.DataDemodModeK91)
		self._core.io.write(f'SENSe:DEMod:DATA {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DataDemodModeK91:
		"""SCPI: [SENSe]:DEMod:DATA \n
		Snippet: value: enums.DataDemodModeK91 = driver.applications.k91Wlan.sense.demod.data.get() \n
		Defines when in the demodulation process the bitstream is determined and thus which results are available. See also 'BER
		and CWER'. \n
			:return: mode: ACDScarrier | ALBDecoder ACDScarrier (Default:) No channel decoding is performed. Processing time is reduced, but BER and CWER results are not available. ALBDecoder Decoding is performed, providing BER and CWER results. Measurement time is increased compared to non-decoding process."""
		response = self._core.io.query_str(f'SENSe:DEMod:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataDemodModeK91)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StopCls:
	"""Stop commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stop", core, parent)

	def set(self, frequency: float, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:LIST:RANGe<ri>[:FREQuency]:STOP \n
		Snippet: driver.sense.listPy.range.frequency.stop.set(frequency = 1.0, rangePy = repcap.RangePy.Default) \n
		This command defines the stop frequency of a spurious emission measurement range. Make sure to set an appropriate span.
		If you set a span that is
			INTRO_CMD_HELP: For triggered gated measurements,only the following gate trigger sources are supported: \n
			- smaller than the span the sweep list covers, the R&S FSW will not measure the ranges that are outside the span - results may be invalid.
			- greater than the span the sweep list covers, the R&S FSW will adjust the start frequency of the first range and the stop frequency of the last range to the span
		For more information see'Spurious emissions measurement' . \n
			:param frequency: Numeric value. Unit: Hz
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.decimal_value_to_str(frequency)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:LIST:RANGe{rangePy_cmd_val}:FREQuency:STOP {param}')

	def get(self, rangePy=repcap.RangePy.Default) -> float:
		"""SCPI: [SENSe]:LIST:RANGe<ri>[:FREQuency]:STOP \n
		Snippet: value: float = driver.sense.listPy.range.frequency.stop.get(rangePy = repcap.RangePy.Default) \n
		This command defines the stop frequency of a spurious emission measurement range. Make sure to set an appropriate span.
		If you set a span that is
			INTRO_CMD_HELP: For triggered gated measurements,only the following gate trigger sources are supported: \n
			- smaller than the span the sweep list covers, the R&S FSW will not measure the ranges that are outside the span - results may be invalid.
			- greater than the span the sweep list covers, the R&S FSW will adjust the start frequency of the first range and the stop frequency of the last range to the span
		For more information see'Spurious emissions measurement' . \n
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:return: frequency: Numeric value. Unit: Hz"""
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		response = self._core.io.query_str(f'SENSe:LIST:RANGe{rangePy_cmd_val}:FREQuency:STOP?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CompensationCls:
	"""Compensation commands group definition. 5 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("compensation", core, parent)

	@property
	def adroop(self):
		"""adroop commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adroop'):
			from .Adroop import AdroopCls
			self._adroop = AdroopCls(self._core, self._cmd_group)
		return self._adroop

	@property
	def freqError(self):
		"""freqError commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_freqError'):
			from .FreqError import FreqErrorCls
			self._freqError = FreqErrorCls(self._core, self._cmd_group)
		return self._freqError

	@property
	def iqOffset(self):
		"""iqOffset commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iqOffset'):
			from .IqOffset import IqOffsetCls
			self._iqOffset = IqOffsetCls(self._core, self._cmd_group)
		return self._iqOffset

	@property
	def iqImbalance(self):
		"""iqImbalance commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iqImbalance'):
			from .IqImbalance import IqImbalanceCls
			self._iqImbalance = IqImbalanceCls(self._core, self._cmd_group)
		return self._iqImbalance

	@property
	def symbolRate(self):
		"""symbolRate commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	def clone(self) -> 'CompensationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CompensationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ColorCls:
	"""Color commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("color", core, parent)

	def set(self, color_scheme: enums.ColorSchemeA, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:SPECtrogram:COLor \n
		Snippet: driver.calculate.spectrogram.color.set(color_scheme = enums.ColorSchemeA.COLD, window = repcap.Window.Default) \n
		This command selects the color scheme. For details see 'Color maps'. \n
			:param color_scheme: HOT Uses a color range from blue to red. Blue colors indicate low levels, red colors indicate high ones. COLD Uses a color range from red to blue. Red colors indicate low levels, blue colors indicate high ones. RADar Uses a color range from black over green to light turquoise with shades of green in between. GRAYscale Shows the results in shades of gray.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.enum_scalar_to_str(color_scheme, enums.ColorSchemeA)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:SPECtrogram:COLor {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.ColorSchemeA:
		"""SCPI: CALCulate<n>:SPECtrogram:COLor \n
		Snippet: value: enums.ColorSchemeA = driver.calculate.spectrogram.color.get(window = repcap.Window.Default) \n
		This command selects the color scheme. For details see 'Color maps'. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: color_scheme: HOT Uses a color range from blue to red. Blue colors indicate low levels, red colors indicate high ones. COLD Uses a color range from red to blue. Red colors indicate low levels, blue colors indicate high ones. RADar Uses a color range from black over green to light turquoise with shades of green in between. GRAYscale Shows the results in shades of gray."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:SPECtrogram:COLor?')
		return Conversions.str_to_scalar_enum(response, enums.ColorSchemeA)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:DISTribution:LLINes[:STATe] \n
		Snippet: driver.applications.k6Pulse.calculate.distribution.llines.state.set(state = False, window = repcap.Window.Default) \n
		Hides or shows the limit lines in the selected Parameter Trend or Parameter Distribution result display. Note that this
		function only has an effect on the visibility of the lines in the graphical displays, it does not affect the limit check
		in general or the display of the limit check results in the table displays. \n
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:DISTribution:LLINes:STATe {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:DISTribution:LLINes[:STATe] \n
		Snippet: value: bool = driver.applications.k6Pulse.calculate.distribution.llines.state.get(window = repcap.Window.Default) \n
		Hides or shows the limit lines in the selected Parameter Trend or Parameter Distribution result display. Note that this
		function only has an effect on the visibility of the lines in the graphical displays, it does not affect the limit check
		in general or the display of the limit check results in the table displays. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: state: ON | OFF | 1 | 0"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DISTribution:LLINes:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class KdataCls:
	"""Kdata commands group definition. 11 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("kdata", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def name(self):
		"""name commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_name'):
			from .Name import NameCls
			self._name = NameCls(self._core, self._cmd_group)
		return self._name

	@property
	def ser(self):
		"""ser commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ser'):
			from .Ser import SerCls
			self._ser = SerCls(self._core, self._cmd_group)
		return self._ser

	@property
	def source(self):
		"""source commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_source'):
			from .Source import SourceCls
			self._source = SourceCls(self._core, self._cmd_group)
		return self._source

	@property
	def prbs(self):
		"""prbs commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_prbs'):
			from .Prbs import PrbsCls
			self._prbs = PrbsCls(self._core, self._cmd_group)
		return self._prbs

	def clone(self) -> 'KdataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = KdataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FeedCls:
	"""Feed commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("feed", core, parent)

	def set(self, window_type: str, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:FEED \n
		Snippet: driver.applications.k17Mcgd.calculate.feed.set(window_type = '1', window = repcap.Window.Default) \n
		This command selects the evaluation method of the measured data that is to be displayed in the specified window.
		This command queries or sets the diagram type (for magnitude or for phase) . Note that this command is maintained for
		compatibility reasons only. Use the LAYout commands for new remote control programs (see 'Working with windows in the
		display') . \n
			:param window_type: 'XFRequency:SPECtrum[:MAGNitude]' Magnitude diagram 'XFRequency:SPECtrum:PHASe' Phase diagram
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.value_to_quoted_str(window_type)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:FEED {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConfigCls:
	"""Config commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("config", core, parent)

	def set(self, no_of_antennas: enums.NoOfMimoAntennas, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:LTE]:DL[:CC<cc>]:MIMO:CONFig \n
		Snippet: driver.applications.k10Xlte.configure.lte.downlink.cc.mimo.config.set(no_of_antennas = enums.NoOfMimoAntennas.TX1, carrierComponent = repcap.CarrierComponent.Default) \n
		This command sets the number of antennas in the MIMO setup. \n
			:param no_of_antennas: TX1 Use one Tx-antenna TX2 Use two Tx-antennas TX4 Use four Tx-antennas
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.enum_scalar_to_str(no_of_antennas, enums.NoOfMimoAntennas)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:LTE:DL:CC{carrierComponent_cmd_val}:MIMO:CONFig {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> enums.NoOfMimoAntennas:
		"""SCPI: CONFigure[:LTE]:DL[:CC<cc>]:MIMO:CONFig \n
		Snippet: value: enums.NoOfMimoAntennas = driver.applications.k10Xlte.configure.lte.downlink.cc.mimo.config.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command sets the number of antennas in the MIMO setup. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: no_of_antennas: TX1 Use one Tx-antenna TX2 Use two Tx-antennas TX4 Use four Tx-antennas"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:LTE:DL:CC{carrierComponent_cmd_val}:MIMO:CONFig?')
		return Conversions.str_to_scalar_enum(response, enums.NoOfMimoAntennas)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConnectorCls:
	"""Connector commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("connector", core, parent)

	def set(self, input_connectors: enums.InputConnectorB, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<Undef>:CONNector \n
		Snippet: driver.applications.k9X11Ad.inputPy.connector.set(input_connectors = enums.InputConnectorB.AIQI, inputIx = repcap.InputIx.Default) \n
		No command help available \n
			:param input_connectors: No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(input_connectors, enums.InputConnectorB)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:CONNector {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.InputConnectorB:
		"""SCPI: INPut<Undef>:CONNector \n
		Snippet: value: enums.InputConnectorB = driver.applications.k9X11Ad.inputPy.connector.get(inputIx = repcap.InputIx.Default) \n
		No command help available \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: input_connectors: No help available"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.InputConnectorB)
